@@ -334,11 +334,34 @@ None by default.
 
 =head1 ACKNOWLEDGEMENTS
 
-Stephen Morgan for creating the TT template and SVG.
+Thanks to Foxtons for letting us put this on CPAN, Todd Caine for heads up on
+reparsing the template (but not using atm), David Meibusch for TimeSeries and a
+load of other ideas, Stephen Morgan for creating the TT template and SVG, and
+thanks for all the patches by Andrew Ruthven and others.
 
 =head1 AUTHOR
 
-Leo Lapworth (LLAP@cuckoo.org)
+Leo Lapworth <LLAP@cuckoo.org>
+
+=head1 MAINTAINER
+
+Florent Angly <florent.angly@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2003, Leo Lapworth 
+
+This module is free software; you can redistribute it or 
+modify it under the same terms as Perl itself.
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-graph-svg-tt@rt.cpan.org, or
+through the web interface at http://rt.cpan.org.
+
+The Graph::SVG::TT development repository is located on GitHub at
+L<http://github.com/ranguard/svg-tt-graph>. Get the latest development version
+using: git clone git://github.com/ranguard/svg-tt-graph.git
 
 =head1 SEE ALSO
 
@@ -576,27 +599,27 @@ __DATA__
 [% max_x_label_size = 0 %]
 <!-- find largest labels values in turn -->
 [% FOREACH field = config.fields %]
-	[% IF max_x_label_size < field.length %]
-		[% max_x_label_size = field.length %]
-	[% END %]
+  [% IF max_x_label_size < field.length %]
+    [% max_x_label_size = field.length %]
+  [% END %]
 
-	[% IF min_value > data.0.data.$field && data.0.data.$field != '' %]
-		[% min_value = data.0.data.$field %]
-	[% END %]
+  [% IF min_value > data.0.data.$field && data.0.data.$field != '' %]
+    [% min_value = data.0.data.$field %]
+  [% END %]
 
-	[% IF max_value < data.0.data.$field && data.0.data.$field != '' %]
-		[% max_value = data.0.data.$field %]
-	[% END %]
+  [% IF max_value < data.0.data.$field && data.0.data.$field != '' %]
+    [% max_value = data.0.data.$field %]
+  [% END %]
 
-	[% IF secondary_max_value < data.1.data.$field && data.1.data.$field != '' %]
-		[% secondary_max_value = data.1.data.$field %]
-	[% END %]
-	[% IF secondary_max_y_label_size < data.1.data.$field.length %]
-		[% secondary_max_y_label_size = data.1.data.$field.length %]
-	[% END %]
-	[% IF max_key_size < data.0.title.length %]
-		[% max_key_size = data.0.title.length %]
-	[% END %]
+  [% IF secondary_max_value < data.1.data.$field && data.1.data.$field != '' %]
+    [% secondary_max_value = data.1.data.$field %]
+  [% END %]
+  [% IF secondary_max_y_label_size < data.1.data.$field.length %]
+    [% secondary_max_y_label_size = data.1.data.$field.length %]
+  [% END %]
+  [% IF max_key_size < data.0.title.length %]
+    [% max_key_size = data.0.title.length %]
+  [% END %]
 [% END %]
 
 
@@ -609,107 +632,107 @@ __DATA__
 
   <!-- reduce height if x labels are rotated -->
   [% max_x_label_length = 0 %]
-	[% IF config.rotate_x_labels %]
-		[% max_x_label_length = max_x_label_size * char_width %]
-		[% h = h - max_x_label_length %]
-	[% END %]
-	
-	<!-- stagger x labels if overlapping occurs -->
-	[% stagger = 0 %]
-	[% IF config.stagger_x_labels %]
-		[% stagger = 17 %]
-		[% h = h - stagger %]
-	[% END %]
-	
-	[% IF config.show_x_title %][% h = h - title_height - stagger %][% END %]
-	
-	<!-- pad top of graph if y axis has data labels so labels do not get chopped off -->
-	[% IF config.show_y_labels %][% h = h - 10 %][% y = y + 10 %][% END %]
-	
-	<!-- reduce height if graph has title or subtitle -->
-	[% IF config.show_graph_title %][% h = h - title_height %][% y = y + title_height %][% END %]
-	[% IF config.show_graph_subtitle %][% h = h - 10 %][% y = y + 10 %][% END %]
-	
+  [% IF config.rotate_x_labels %]
+    [% max_x_label_length = max_x_label_size * char_width %]
+    [% h = h - max_x_label_length %]
+  [% END %]
+  
+  <!-- stagger x labels if overlapping occurs -->
+  [% stagger = 0 %]
+  [% IF config.stagger_x_labels %]
+    [% stagger = 17 %]
+    [% h = h - stagger %]
+  [% END %]
+  
+  [% IF config.show_x_title %][% h = h - title_height - stagger %][% END %]
+  
+  <!-- pad top of graph if y axis has data labels so labels do not get chopped off -->
+  [% IF config.show_y_labels %][% h = h - 10 %][% y = y + 10 %][% END %]
+  
+  <!-- reduce height if graph has title or subtitle -->
+  [% IF config.show_graph_title %][% h = h - title_height %][% y = y + title_height %][% END %]
+  [% IF config.show_graph_subtitle %][% h = h - 10 %][% y = y + 10 %][% END %]
+  
 <!-- reduce graph dimensions if there is a KEY -->
-	[% key_box_size = 12 %]
-	
-	[% IF config.key && config.key_position == 'right' %]
-		[% IF config.show_secondary_y_title %]
-			[% w = w - (max_key_size * (char_width - 1)) - (key_box_size * 3 ) %]
-		[% ELSE %]
-			[% w = w - (max_key_size * (char_width - 1)) - (key_box_size * 3 ) - title_height %]
-		[% END %]
-	[% ELSIF config.key && config.key_position == 'bottom' %]
+  [% key_box_size = 12 %]
+  
+  [% IF config.key && config.key_position == 'right' %]
+    [% IF config.show_secondary_y_title %]
+      [% w = w - (max_key_size * (char_width - 1)) - (key_box_size * 3 ) %]
+    [% ELSE %]
+      [% w = w - (max_key_size * (char_width - 1)) - (key_box_size * 3 ) - title_height %]
+    [% END %]
+  [% ELSIF config.key && config.key_position == 'bottom' %]
     [% IF data.size < 4 %]
       [% h = h - ((data.size + 1) * (key_box_size + key_padding))%]
     [% ELSE %]
       [% h = h - (4 * (key_box_size + key_padding))%]
     [% END %]        
-	[% END %]
+  [% END %]
 
-	<!-- find start value for scale on y axis -->
-	[% IF config.min_scale_value || config.min_scale_value == '0' %]
-		[% min_scale_value = config.min_scale_value %]
-	[% ELSE %]
-		<!-- setting lowest value to be min_value as no min_scale_value defined -->
-		[% min_scale_value = min_value %]
-	[% END %]
-	
-	<!-- base line -->
-	[% base_line = h + y %]
-	
-	<!-- how much padding between largest bar and top of graph -->
-	[% IF (max_value - min_scale_value) == 0 %]
-		[% top_pad = 10 %]
-	[% ELSE %]
-		[% top_pad = (max_value - min_scale_value) / 20 %]	
-	[% END %]	
-	
-	<!-- how much padding between largest bar and top of graph for secondary y axis -->
-	[% IF (secondary_max_value - min_scale_value) == 0 %]
-		[% secondary_top_pad = 10 %]
-	[% ELSE %]
-		[% secondary_top_pad = (secondary_max_value - min_scale_value) / 20 %]	
-	[% END %]	
-	
-	[% scale_range = (max_value + top_pad) - min_scale_value %]
-	[% secondary_scale_range = (secondary_max_value + secondary_top_pad) - min_scale_value %]
+  <!-- find start value for scale on y axis -->
+  [% IF config.min_scale_value || config.min_scale_value == '0' %]
+    [% min_scale_value = config.min_scale_value %]
+  [% ELSE %]
+    <!-- setting lowest value to be min_value as no min_scale_value defined -->
+    [% min_scale_value = min_value %]
+  [% END %]
+  
+  <!-- base line -->
+  [% base_line = h + y %]
+  
+  <!-- how much padding between largest bar and top of graph -->
+  [% IF (max_value - min_scale_value) == 0 %]
+    [% top_pad = 10 %]
+  [% ELSE %]
+    [% top_pad = (max_value - min_scale_value) / 20 %]
+  [% END %]
+  
+  <!-- how much padding between largest bar and top of graph for secondary y axis -->
+  [% IF (secondary_max_value - min_scale_value) == 0 %]
+    [% secondary_top_pad = 10 %]
+  [% ELSE %]
+    [% secondary_top_pad = (secondary_max_value - min_scale_value) / 20 %]
+  [% END %]
+  
+  [% scale_range = (max_value + top_pad) - min_scale_value %]
+  [% secondary_scale_range = (secondary_max_value + secondary_top_pad) - min_scale_value %]
 
-	<!-- default to 10 scale_divisions if none have been set -->
-	[% IF config.scale_divisions %]
-		[% scale_division = config.scale_divisions %]
-	[% ELSE %]
-		[% scale_division = scale_range / 10 FILTER format('%2.01f') %]
-	[% END %]
-	
+  <!-- default to 10 scale_divisions if none have been set -->
+  [% IF config.scale_divisions %]
+    [% scale_division = config.scale_divisions %]
+  [% ELSE %]
+    [% scale_division = scale_range / 10 FILTER format('%2.01f') %]
+  [% END %]
+  
   <!-- default to 10 scale_divisions if none have been set for secondary y axis -->
-	[% IF config.scale_divisions %]
-		[% secondary_scale_division = config.scale_divisions %]
-	[% ELSE %]
-		[% secondary_scale_division = secondary_scale_range / 10 FILTER format('%2.01f') %]
-	[% END %]
+  [% IF config.scale_divisions %]
+    [% secondary_scale_division = config.scale_divisions %]
+  [% ELSE %]
+    [% secondary_scale_division = secondary_scale_range / 10 FILTER format('%2.01f') %]
+  [% END %]
 
-	[% IF config.scale_integers %]
-		[% IF scale_division < 1 %]
-			[% scale_division = 1 %]
-		[% ELSIF scale_division.match('.') %]
-			[% scale_division = scale_division FILTER format('%2.0f') %]
-		[% END %]
-	[% END %]
-	
+  [% IF config.scale_integers %]
+    [% IF scale_division < 1 %]
+      [% scale_division = 1 %]
+    [% ELSIF scale_division.match('.') %]
+      [% scale_division = scale_division FILTER format('%2.0f') %]
+    [% END %]
+  [% END %]
+  
 <!-- JUMP THE GUN AND CALC BAR WIDTHS AS THESE ARE USED FOR PADDING IF LARGE X LABELS ARE USED -->
 <!-- get number of data points on x scale -->
 [% dx = config.fields.size %]
 
 [% secondary_title_padding = 0 %]
 [% IF config.show_secondary_y_labels %]
-	[% w = w - secondary_max_y_label_length - title_height %]
-	[% secondary_title_padding = secondary_title_padding + secondary_max_y_label_length + 10 %]
+  [% w = w - secondary_max_y_label_length - title_height %]
+  [% secondary_title_padding = secondary_title_padding + secondary_max_y_label_length + 10 %]
 [% END %]
 
 [% IF config.show_secondary_y_title %]
-	[% w = w - title_height - char_width %]
-	[% secondary_title_padding = secondary_title_padding + title_height %]
+  [% w = w - title_height - char_width %]
+  [% secondary_title_padding = secondary_title_padding + title_height %]
 [% END %]
 
 
@@ -724,16 +747,16 @@ __DATA__
 
 [% space_b4_y_axis = 0 %]
 [% IF half_label_width > (dw / 2) %]
-	<!-- calc difference and pad accordingly -->
-	[% space_b4_y_axis = half_label_width - (dw / 2) %]
-	<!-- only need to pad the left side if a key is present -->
-	[% IF config.key && config.key_position == 'right' %]
-		[% w = w - space_b4_y_axis %]
-	[% ELSE %]
-		<!-- pad both sides -->
-		[% w = w - (space_b4_y_axis * 2) %]
-	[% END %]
-	[% x = x + space_b4_y_axis %]
+  <!-- calc difference and pad accordingly -->
+  [% space_b4_y_axis = half_label_width - (dw / 2) %]
+  <!-- only need to pad the left side if a key is present -->
+  [% IF config.key && config.key_position == 'right' %]
+    [% w = w - space_b4_y_axis %]
+  [% ELSE %]
+    <!-- pad both sides -->
+    [% w = w - (space_b4_y_axis * 2) %]
+  [% END %]
+  [% x = x + space_b4_y_axis %]
 [% END %]
 
 <!-- find the string length of max value -->
@@ -744,19 +767,19 @@ __DATA__
 <!-- If the y labels are shown but the size of the x labels are small, pad for y labels -->
 
 [% IF config.show_y_labels && space_b4_y_axis < max_value_length_px %]
-	<!-- allow slightly more padding if small labels -->
-	[% IF max_value_length < 2 %]
-		[% w = w - (max_value_length * (char_width * 2)) %]
-		[% x = x + (max_value_length * (char_width * 2)) %]
-	[% ELSE %]
-		[% w = w - max_value_length_px %]
-		[% x = x + max_value_length_px %]
-	[% END %]
+  <!-- allow slightly more padding if small labels -->
+  [% IF max_value_length < 2 %]
+    [% w = w - (max_value_length * (char_width * 2)) %]
+    [% x = x + (max_value_length * (char_width * 2)) %]
+  [% ELSE %]
+    [% w = w - max_value_length_px %]
+    [% x = x + max_value_length_px %]
+  [% END %]
 [% END %]
 
 [% IF config.show_y_title && space_b4_y_axis < max_value_length_px %]
-	[% w = w - title_height %]
-	[% x = x + title_height %]
+  [% w = w - title_height %]
+  [% x = x + title_height %]
 [% END %]
 
 
@@ -782,10 +805,10 @@ __DATA__
 [% IF config.bar_gap %]
   [% bar_gap = 10 %]
   [% IF dw < bar_gap %]
-		[% bar_gap = dw / 2 %]
-	[% END %]
+    [% bar_gap = dw / 2 %]
+  [% END %]
 [% ELSE %]
-	[% bar_gap = 0 %]
+  [% bar_gap = 0 %]
 [% END %]
 
 [% i = dw %]
@@ -794,24 +817,24 @@ __DATA__
 
 <!-- x axis labels -->
 [% IF config.show_x_labels %]
-	[% FOREACH field = config.fields %]
-        [% field_txt = config.x_label_formatter(field) %]
-		[% IF count == 0 %]
+  [% FOREACH field = config.fields %]
+    [% field_txt = config.x_label_formatter(field) %]
+    [% IF count == 0 %]
       <text x="[% x + (dw / 2) - (bar_gap / 2) %]" y="[% base_line + 15 %]" [% IF config.rotate_x_labels %]transform="rotate(90 [% x + (dw / 2) - (bar_gap / 2) - half_char_height %] [% base_line + 15 %])" style="text-anchor: start" [% END %]class="xAxisLabels">[% field %]</text>
-		  [% i = i - dw %]
-		[% ELSE %]
-			[% IF stagger_count == 2 %]
-				<text x="[% x + i + (dw / 2) - (bar_gap / 2) %]" y="[% base_line + 15 %]" [% IF config.rotate_x_labels %]transform="rotate(90 [% x + i + (dw / 2) - (bar_gap / 2) - half_char_height %] [% base_line + 15 %])" style="text-anchor: start" [% END %]class="xAxisLabels">[% field_txt %]</text>
-				[% stagger_count = 0 %]
-			[% ELSE %]
-				<text x="[% x + i + (dw / 2) - (bar_gap / 2) %]" y="[% base_line + 15 + stagger %]" [% IF config.rotate_x_labels %]transform="rotate(90 [% x + i + (dw / 2) - (bar_gap / 2) - half_char_height %] [% base_line + 15 + stagger %])" style="text-anchor: start" [% END %]class="xAxisLabels">[% field_txt %]</text>
-				<path d="M[% x + i + (dw / 2) - (bar_gap / 2) %] [% base_line %] v[% stagger %]" class="staggerGuideLine" />
-			[% END %]
-		[% END %]
-	  [% i = i + dw %]
-	  [% count = count + 1 %]
-	  [% stagger_count = stagger_count + 1 %]
-	[% END %]
+      [% i = i - dw %]
+    [% ELSE %]
+      [% IF stagger_count == 2 %]
+        <text x="[% x + i + (dw / 2) - (bar_gap / 2) %]" y="[% base_line + 15 %]" [% IF config.rotate_x_labels %]transform="rotate(90 [% x + i + (dw / 2) - (bar_gap / 2) - half_char_height %] [% base_line + 15 %])" style="text-anchor: start" [% END %]class="xAxisLabels">[% field_txt %]</text>
+        [% stagger_count = 0 %]
+      [% ELSE %]
+        <text x="[% x + i + (dw / 2) - (bar_gap / 2) %]" y="[% base_line + 15 + stagger %]" [% IF config.rotate_x_labels %]transform="rotate(90 [% x + i + (dw / 2) - (bar_gap / 2) - half_char_height %] [% base_line + 15 + stagger %])" style="text-anchor: start" [% END %]class="xAxisLabels">[% field_txt %]</text>
+        <path d="M[% x + i + (dw / 2) - (bar_gap / 2) %] [% base_line %] v[% stagger %]" class="staggerGuideLine" />
+      [% END %]
+    [% END %]
+    [% i = i + dw %]
+    [% count = count + 1 %]
+    [% stagger_count = stagger_count + 1 %]
+  [% END %]
 [% END %]
 
 
@@ -823,18 +846,18 @@ __DATA__
 [% count = 0 %]
 [% y_value = min_scale_value %]
 [% IF config.show_y_labels %]
-	[% WHILE (dy * count) < h %]
-        [% y_value_txt = config.y_label_formatter(y_value) %]
-		[% IF count == 0 %]
-  		<!-- no stroke for first line -->
-			<text x="[% x - 5 %]" y="[% base_line - (dy * count) %]" class="yAxisLabels">[% y_value_txt %]</text>
-		[% ELSE %]
-			<text x="[% x - 5 %]" y="[% base_line - (dy * count) %]" class="yAxisLabels">[% y_value_txt %]</text>
-			<path d="M[% x %] [% base_line - (dy * count) %] h[% w %]" class="guideLines"/>
-		[% END %]
-		[% y_value = y_value + scale_division %]
-		[% count = count + 1 %]
-	[% END %]
+  [% WHILE (dy * count) < h %]
+    [% y_value_txt = config.y_label_formatter(y_value) %]
+    [% IF count == 0 %]
+      <!-- no stroke for first line -->
+      <text x="[% x - 5 %]" y="[% base_line - (dy * count) %]" class="yAxisLabels">[% y_value_txt %]</text>
+    [% ELSE %]
+      <text x="[% x - 5 %]" y="[% base_line - (dy * count) %]" class="yAxisLabels">[% y_value_txt %]</text>
+      <path d="M[% x %] [% base_line - (dy * count) %] h[% w %]" class="guideLines"/>
+    [% END %]
+    [% y_value = y_value + scale_division %]
+    [% count = count + 1 %]
+  [% END %]
 [% END %]
 
 
@@ -846,12 +869,12 @@ __DATA__
 [% s_count = 0 %]
 [% secondary_y_value = min_scale_value %]
 [% IF config.show_secondary_y_labels %]
-	[% WHILE (dy * s_count) < h %]
-		<text x="[% x + w + 5 %]" y="[% base_line - (dy * s_count) %]" class="yAxisLabels" style="text-anchor: start">[% secondary_y_value %]</text>
+  [% WHILE (dy * s_count) < h %]
+    <text x="[% x + w + 5 %]" y="[% base_line - (dy * s_count) %]" class="yAxisLabels" style="text-anchor: start">[% secondary_y_value %]</text>
 
-		[% secondary_y_value = secondary_y_value + secondary_scale_division %]
-		[% s_count = s_count + 1 %]
-	[% END %]
+    [% secondary_y_value = secondary_y_value + secondary_scale_division %]
+    [% s_count = s_count + 1 %]
+  [% END %]
 [% END %]
 
 
@@ -859,30 +882,30 @@ __DATA__
 
 <!-- x axis title -->
 [% IF config.show_x_title %]
-	[% IF !config.show_x_labels %]
-		[% y_xtitle = 15 %]
-	[% ELSE %]
-		[% y_xtitle = 35 %]
-	[% END %]
-	<text x="[% (w / 2) + x %]" y="[% h + y + y_xtitle + stagger + max_x_label_length %]" class="xAxisTitle">[% config.x_title %]</text>
+  [% IF !config.show_x_labels %]
+    [% y_xtitle = 15 %]
+  [% ELSE %]
+    [% y_xtitle = 35 %]
+  [% END %]
+  <text x="[% (w / 2) + x %]" y="[% h + y + y_xtitle + stagger + max_x_label_length %]" class="xAxisTitle">[% config.x_title %]</text>
 [% END %]
 
 <!-- y axis title -->
 [% IF config.show_y_title %]
-	[% IF config.y_title_text_direction == 'tb' %]
-		<text x="11" y="[% (h / 2) + y %]" class="yAxisTitle" style="writing-mode:tb;">[% config.y_title %]</text>
-	[% ELSE %]
-		<text class="yAxisTitle" transform="translate(15,[% (h / 2) + y %]) rotate(270)">[% config.y_title %]</text>
-	[% END %]
+  [% IF config.y_title_text_direction == 'tb' %]
+    <text x="11" y="[% (h / 2) + y %]" class="yAxisTitle" style="writing-mode:tb;">[% config.y_title %]</text>
+  [% ELSE %]
+    <text class="yAxisTitle" transform="translate(15,[% (h / 2) + y %]) rotate(270)">[% config.y_title %]</text>
+  [% END %]
 [% END %]
 
 <!-- secondary y axis title -->
 [% IF config.show_secondary_y_title %]
-	[% IF config.secondary_y_title_text_direction == 'tb' %]
-		<text x="[% x + w + secondary_title_padding %]" y="[% (h / 2) + y %]" class="yAxisTitle" style="writing-mode:tb;">[% config.secondary_y_title %]</text>
-	[% ELSE %]
-		<text class="yAxisTitle" transform="translate([% x + w + secondary_title_padding %],[% (h / 2) + y %]) rotate(270)">[% config.secondary_y_title %]</text>
-	[% END %]
+  [% IF config.secondary_y_title_text_direction == 'tb' %]
+    <text x="[% x + w + secondary_title_padding %]" y="[% (h / 2) + y %]" class="yAxisTitle" style="writing-mode:tb;">[% config.secondary_y_title %]</text>
+  [% ELSE %]
+    <text class="yAxisTitle" transform="translate([% x + w + secondary_title_padding %],[% (h / 2) + y %]) rotate(270)">[% config.secondary_y_title %]</text>
+  [% END %]
 [% END %]
 
 
@@ -897,13 +920,13 @@ __DATA__
 
 <!-- Draw BAR CHART -->
 [% FOREACH field = config.fields %]
-	[% dcount = 1 %]
-	<path d="M[% x + (dw * xcount) %] [% base_line %] V[% base_line - (data.0.data.$field * divider) %] h[% bar_width %] V[% base_line %] Z" class="fill[% dcount %]"/>
-	[% IF config.show_data_values %]
-		<text x="[% (dw * xcount) + x + (dw / 2) - (bar_gap / 2) %]" y="[% base_line - (data.0.data.$field * divider) - 6 %]" class="dataPointLabel">[% data.0.data.$field %]</text>
-	[% END %]
-	[% dcount = dcount + 1 %]	
-  [% xcount = xcount + 1 %]		
+  [% dcount = 1 %]
+  <path d="M[% x + (dw * xcount) %] [% base_line %] V[% base_line - (data.0.data.$field * divider) %] h[% bar_width %] V[% base_line %] Z" class="fill[% dcount %]"/>
+  [% IF config.show_data_values %]
+    <text x="[% (dw * xcount) + x + (dw / 2) - (bar_gap / 2) %]" y="[% base_line - (data.0.data.$field * divider) - 6 %]" class="dataPointLabel">[% data.0.data.$field %]</text>
+  [% END %]
+  [% dcount = dcount + 1 %]
+  [% xcount = xcount + 1 %]
 [% END %]
 
 <!-- Draw Line graph -->
@@ -934,50 +957,50 @@ __DATA__
 [% key_count = 1 %]
 [% key_padding = 5 %]
 [% IF config.key && config.key_position == 'right' %]
-	[% FOREACH dataset = data %]
-		<rect x="[% x + w + 20 + secondary_max_y_label_length + title_height %]" y="[% y + (key_box_size * key_count) + (key_count * key_padding) %]" width="[% key_box_size %]" height="[% key_box_size %]" class="key[% key_count %]"/>
-		<text x="[% x + w + 20 + key_box_size + key_padding + secondary_max_y_label_length + title_height %]" y="[% y + (key_box_size * key_count) + (key_count * key_padding) + key_box_size %]" class="keyText">[% dataset.title %]</text>
-		[% key_count = key_count + 1 %]
-	[% END %]
+  [% FOREACH dataset = data %]
+    <rect x="[% x + w + 20 + secondary_max_y_label_length + title_height %]" y="[% y + (key_box_size * key_count) + (key_count * key_padding) %]" width="[% key_box_size %]" height="[% key_box_size %]" class="key[% key_count %]"/>
+    <text x="[% x + w + 20 + key_box_size + key_padding + secondary_max_y_label_length + title_height %]" y="[% y + (key_box_size * key_count) + (key_count * key_padding) + key_box_size %]" class="keyText">[% dataset.title %]</text>
+    [% key_count = key_count + 1 %]
+  [% END %]
 [% ELSIF config.key && config.key_position == 'bottom' %]
-	<!-- calc y position of start of key -->
-	[% y_key = base_line %]
-	[% IF config.show_x_title %][% y_key = y_key + title_height %][% END %]
-	[% IF config.rotate_x_labels && config.show_x_labels %]
-		[% y_key = y_key + max_x_label_length %]
-	[% ELSIF config.show_x_labels && stagger < 1 %]
-		[% y_key = y_key + 20 %]
-	[% END %]
-	
-	[% y_key_start = y_key %]
-	[% x_key = x %]
-	[% FOREACH dataset = data %]
-		[% IF key_count == 4 || key_count == 7 || key_count == 10 %]
-  		<!-- wrap key every 3 entries -->
-			[% x_key = x_key + 200 %]
-			[% y_key = y_key - (key_box_size * 4) - 2 %]
-		[% END %]
-		<rect x="[% x_key %]" y="[% y_key + (key_box_size * key_count) + (key_count * key_padding) + stagger %]" width="[% key_box_size %]" height="[% key_box_size %]" class="key[% key_count %]"/>
-		<text x="[% x_key + key_box_size + key_padding %]" y="[% y_key + (key_box_size * key_count) + (key_count * key_padding) + key_box_size + stagger %]" class="keyText">[% dataset.title %]</text>
-		[% key_count = key_count + 1 %]
-	[% END %]
-	
+  <!-- calc y position of start of key -->
+  [% y_key = base_line %]
+  [% IF config.show_x_title %][% y_key = y_key + title_height %][% END %]
+  [% IF config.rotate_x_labels && config.show_x_labels %]
+    [% y_key = y_key + max_x_label_length %]
+  [% ELSIF config.show_x_labels && stagger < 1 %]
+    [% y_key = y_key + 20 %]
+  [% END %]
+  
+  [% y_key_start = y_key %]
+  [% x_key = x %]
+  [% FOREACH dataset = data %]
+    [% IF key_count == 4 || key_count == 7 || key_count == 10 %]
+      <!-- wrap key every 3 entries -->
+      [% x_key = x_key + 200 %]
+      [% y_key = y_key - (key_box_size * 4) - 2 %]
+    [% END %]
+    <rect x="[% x_key %]" y="[% y_key + (key_box_size * key_count) + (key_count * key_padding) + stagger %]" width="[% key_box_size %]" height="[% key_box_size %]" class="key[% key_count %]"/>
+    <text x="[% x_key + key_box_size + key_padding %]" y="[% y_key + (key_box_size * key_count) + (key_count * key_padding) + key_box_size + stagger %]" class="keyText">[% dataset.title %]</text>
+    [% key_count = key_count + 1 %]
+  [% END %]
+  
 [% END %]
 
 <!-- //////////////////////////////// MAIN TITLES ////////////////////////// -->
 
 <!-- main graph title -->
 [% IF config.show_graph_title %]
-	<text x="[% config.width / 2 %]" y="15" class="mainTitle">[% config.graph_title %]</text>
+  <text x="[% config.width / 2 %]" y="15" class="mainTitle">[% config.graph_title %]</text>
 [% END %]
 
 <!-- graph sub title -->
 [% IF config.show_graph_subtitle %]
-	[% IF config.show_graph_title %]
-		[% y_subtitle = 30 %]
-	[% ELSE %]
-		[% y_subtitle = 15 %]
-	[% END %]
-	<text x="[% config.width / 2 %]" y="[% y_subtitle %]" class="subTitle">[% config.graph_subtitle %]</text>
+  [% IF config.show_graph_title %]
+    [% y_subtitle = 30 %]
+  [% ELSE %]
+    [% y_subtitle = 15 %]
+  [% END %]
+  <text x="[% config.width / 2 %]" y="[% y_subtitle %]" class="subTitle">[% config.graph_subtitle %]</text>
 [% END %]
 </svg>
